;=========================================================================
;|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
;=========================================================================
;TTSapi5.inc            PROTOTYPES     and     DESCRIPTION
;
;
; http://www.dougiem.fsnet.co.uk/asm
;
;=========================================================================
;|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
;=========================================================================

InitCom              PROTO :dword,:dword ;    hwin,wparam
;        This should be called in WM_CREATE. hwin is the handle of the main 
;        calling window.
;        wparam is the wParam number you want WM_COMMAND to use for the follwing 
;        notifications : wParam   = change in speech running status
;                         lParam  = 0=pause 2=running 1 or 3=end of output
;                        wParam+1 = word boundary found
;                         lParam  = hi word = ix0 position. lo word = length
;                        wParam+2 = change in viseme id number [Visual Emulation]
;                         lParam  = the ID number associated with the sound.
;                                   The mouth forms can be seen in \rs\mouth_x.bmp
;If the function fails, the return value is NON ZERO
;=================================================================================

SpeakCom             PROTO :dword,:dword ;    addrData,flags
;        addrData is the address of an ANSI zero string to speak.
;        flags are: SPF_DEFAULT,SPF_ASYNC,SPF_PURGEBEFORESPEAK,SPF_IS_FILENAME
;                   SPF_IS_XML,SPF_IS_NOT_XML.
;        normal opperation (SPF_ASYNC || SPF_IS_XML) is used. XML tags can be used
;        within the string, I have listed them in readme.asm. A detailed explanation 
;        is in the sapi5 SDK.
;If the function fails, the return value is NON ZERO
;=================================================================================

SkipCom              PROTO :dword        ;    nData
;        nData is the number of sentences to skip
;        only sentences are supported on sapi5.1
;If the function fails, the return value is NEGATIVE
;else returns the number of actual skipped sentences
;=================================================================================

SpeedCom             PROTO :dword        ;    nData
;        nData is the rate at which the speech is output. [valid values = -10 to 10]
;If the function fails, the return value is NON ZERO
;=================================================================================

VolumeCom            PROTO :dword        ;    nData
;        nData is a percentage of the maximum volume the speech is output. 
;        [valid values = 0 to 100]
;If the function fails, the return value is NON ZERO

;=================================================================================

SetAVoiceCom         PROTO :dword        ;    nData
;        nData is the voice number to set SAPI 5.1 to use. It does not change
;        the default voice set by 'Control Panel/voices'
;returns with address of ANSI string of voice name
;If the function fails, the return value is ZERO
;=================================================================================

GetNumberOfVoicesCom PROTO               
;        returns the number of voices installed with SAPI 5.1
;If the function fails, the return value is ZERO
;=================================================================================

SaveWaveCom          PROTO :dword,:dword,:dword ;addrName,addrData,type
;        addrName is the address of an ANSI string containing the file name to use.
;        this uses a create always flag, so checks, if any, should be before calling.
;        addrData is address of the ANSI text data to record.
;        type is an integer from 1 to 4 which coresponds to :
;        1 = 11 Khz 8 bit    2 = 11 Khz 16 bit
;        3 = 22 Khz 16 bit   4 = 44 Khz 16 bit
;     note: Because we want the main window to keep control, the recording is done
;           asynchonously. This means the function leaves the filestream open. 
;           Sapi turns off notifications when writing to file so, 
;           it MUST be closed at the end of the recording by using StopWaveCom, 
;           or abort it, using StopCom.
;If the function fails, the return value is NON ZERO
;=================================================================================

StopWaveCom          PROTO   
;        once SaveWaveCom has been successfully called, this would 
;        typically be called by a [ SetTimer,hwin,int,100,addr StopWaveCom ],
;        calling every 100 msec until 0 returned. The counter is useful 
;        as a graphic ID number.
;returns eax = 0  = wave to file has finished and StopWaveCom has closed the stream
;or returns a counter [start = 1]incremented on every call.
;=================================================================================

PlayWaveCom          PROTO :dword        ;    addrName
;        addrData is address of an ANSI string containing the wave file name to play.
;     note: Because we want the main window to keep control, the playback is done
;           asynchonously. This means the function leaves the filestream open.
;           However sapi WILL send notification [WM_COMMAND,wparam,1 or 3] of the 
;           end of stream (unlike SaveWaveCom}. StopCom should be called 
;           then to close the stream.
;If the function fails, the return value is NON ZERO
;=================================================================================

PauseCom             PROTO
;        on pause a notification [WM_COMMAND,wparam,0] is posted
;If the function fails, the return value is NON ZERO
;=================================================================================

ResumeCom            PROTO
;        on resume a notification [WM_COMMAND,wparam,2] is posted
;If the function fails, the return value is NON ZERO
;=================================================================================

StopCom              PROTO
;        on stop a notification [WM_COMMAND,wparam,1 or 3] is posted
;        This also closes a filestream if its open. This function is actually
;        SpeakCom sending a NULL character with the flags set to:
;        (SPF_PURGEBEFORESPEAK || SPF_ASYNC)
;If the function fails, the return value is NON ZERO
;=================================================================================

EndCom               PROTO
;Must be called before closing application
;=================================================================================

PollStatCom          PROTO 
;        This function returns the running status of sapi. it can be called
;        anytime. Return value is:
;eax hi byte = dwRunningState [24-31]
;       word = ulInputWordPos [ 8-23]
;       byte = ulInputWordLen [ 0- 7]
;If the function fails, the return value is NON ZERO
;=================================================================================

GetVoicesCom         PROTO :dword        ;*   nData
;        should not be called by the application. It is called by SetVoiceCom.and
;        GetNumberOfVoicesCom. see listing
;=================================================================================

UniText              PROTO :dword        ;*   addrData getv savwav
;        should not be called by the application. It is called by GetVoicesCom.
;        200 bytes fixed. See listing
;=================================================================================

TextUni              PROTO :dword        ;*   addrData
;        should not be called by the application. It is called by SpeakCom and
;        SaveWaveCom. Freeing memory critical. See listing
;=================================================================================
;
;

; macros By NaN, 2002: 

;==============================================================
; E-Z Unicode By NaN, 2002
;==============================================================
UNICODE_TEXT TEXTEQU <LABEL BYTE>
LL macro btext
   LOCAL cnt, va, vb, LineText, data1
   LineText TEXTEQU < dw >
   va = 1
   vb = 1
   cnt equ @SizeStr(<btext>)+1
   WHILE va LT cnt
     if vb LT 20
      data1 SUBSTR <btext>, va, 1
      LineText CATSTR LineText, <'>, data1, <',>
     else
      vb = 1
       LineText SUBSTR LineText, 1, @SizeStr(%LineText)-1
       &LineText
       LineText TEXTEQU < dw >
       data1 SUBSTR <btext>, va, 1
       LineText CATSTR LineText, <'>, data1, <',>
     endif
     vb = vb + 1
     va = va + 1
   ENDM
     LineText SUBSTR LineText, 1, @SizeStr(%LineText)-1
     &LineText      
endm
;==============================================================
; E-Z COM Release, by NaN, 2002
;==============================================================
OLE_FREE MACRO pInterface
 .if ( pInterface != NULL )
   ole32 pInterface, 08h      ;; IUnknown_Release
   xor eax, eax
   mov pInterface,eax         ;; Set pInterface = NULL
 .endif                       ;; Return with ole result in eax
ENDM
;==============================================================
; E-Z OLE Calling By Ancev, modified by NaN, 2002
;==============================================================
ole32  macro object, method, rest:VARARG
      LOCAL newlist
      newlist TEXTEQU <>
      
       ifnb <rest>
         for c, <rest>
           newlist CATSTR <c>, <,>,newlist
         ENDM
       newlist SUBSTR newlist, 1, @SizeStr(%newlist)-1
       newlist CATSTR <!<>, newlist, <!>>
       ;;%echo newlist       
       %for  reg, newlist
           push reg
       ENDM     
    endif
       mov eax, [object]
       push eax
       mov eax, [eax]
       call DWORD PTR [eax+method]
endm

;==============================================================
; E-Z GUID Converting from C++ to MASM, by NaN, 2002
;==============================================================
MGUID macro a_c_guid
      LOCAL guidsize, guid1, guid2, guid3, guid4, guid5, guid6, guid7, guid8, guid9, guid10, guid11
      quidsize = @SizeStr(a_c_guid)
      if quidsize eq 36
         guid1 SUBSTR <a_c_guid>, 1, 8
         guid1 CATSTR <0>,guid1,<H>
         guid2 SUBSTR <a_c_guid>, 10, 4
         guid2 CATSTR <0>,guid2,<H>
         guid3 SUBSTR <a_c_guid>, 15, 4
         guid3 CATSTR <0>,guid3,<H>
         guid4 SUBSTR <a_c_guid>, 20, 2
         guid4 CATSTR <0>,guid4,<H>
         guid5 SUBSTR <a_c_guid>, 22, 2
         guid5 CATSTR <0>,guid5,<H>
         guid6 SUBSTR <a_c_guid>, 25, 2
         guid6 CATSTR <0>,guid6,<H>
         guid7 SUBSTR <a_c_guid>, 27, 2
         guid7 CATSTR <0>,guid7,<H>
         guid8 SUBSTR <a_c_guid>, 29, 2
         guid8 CATSTR <0>,guid8,<H>
         guid9 SUBSTR <a_c_guid>, 31, 2
         guid9 CATSTR <0>,guid9,<H>
         guid10 SUBSTR <a_c_guid>, 33, 2
         guid10 CATSTR <0>,guid10,<H>
         guid11 SUBSTR <a_c_guid>, 35, 2
         guid11 CATSTR <0>,guid11,<H>
      else
         echo
         echo FORMAT:  LABEL MGUID (0000000-0000-0000-0000-000000000000)
         echo Must be 36 bytes long, including dashes!
         echo
         .err <MGUID ERROR>
      endif
      exitm <TEXTEQU !<{guid1, guid2, guid3, {guid4, guid5, guid6, guid7, guid8, guid9, guid10, guid11}}!> >     
endm      



;==============================================================
; E-Z COM Error Handling, by NaN, 2002
;==============================================================
IF_COM_ERROR MACRO COM_TXT
   LOCAL txtname

   .data
      txtname  db  COM_TXT,0
   .code
   .if eax == 1
      mov edx, offset txtname
      ret
   .endif
ENDM


  SPFEI MACRO SPEI_ord
   LOCAL aa
   aa =  SPEI_ord
   mov eax, 1
   mov edx, eax
   if aa GT 31
      aa = aa - 32
     if aa GT 0 
%     shl edx, aa
     endif
      or edx, 00000002h
      mov eax, 40000000h
   else
%     shl eax, aa
      or eax, 40000000h
      mov edx, 00000002h
   endif
 endm
 
 Q64 MACRO eedx, eeax
   exitm < eedx, eeax >
 ENDM




EXIT_FUNCTION_OK  TEXTEQU <xor edx, edx>
FUNCTION_ERROR    TEXTEQU < (edx !!= NULL) >

; == Status Flags ==========

SPRS_IS_WAITING      equ 0          ; paused
SPRS_DONE_1          equ 3          ; stopped, when using _async flag on speak ?

		 SPEI_UNDEFINED           equ 0
  ;//--- TTS engine
    SPEI_START_INPUT_STREAM  equ 1
    SPEI_END_INPUT_STREAM    equ 2
    SPEI_VOICE_CHANGE        equ 3  ;   // LPARAM_IS_TOKEN
    SPEI_TTS_BOOKMARK        equ 4  ;   // LPARAM_IS_STRING
    SPEI_WORD_BOUNDARY       equ 5  ;
    SPEI_PHONEME             equ 6  ;
    SPEI_SENTENCE_BOUNDARY   equ 7  ;
    SPEI_VISEME              equ 8  ;
    SPEI_TTS_AUDIO_LEVEL     equ 9  ;   // wParam contains current output audio level

;//--- Viseme features
    SPVFEATURE_STRESSED equ 1
    SPVFEATURE_EMPHASIS equ 2
    
    SP_VISEME_0   equ 0    ;     // Silence
    SP_VISEME_1   equ 1    ;     // AE, AX, AH
    SP_VISEME_2   equ 2    ;     // AA
    SP_VISEME_3   equ 3    ;     // AO
    SP_VISEME_4   equ 4    ;     // EY, EH, UH
    SP_VISEME_5   equ 5    ;     // ER
    SP_VISEME_6   equ 6    ;     // y, IY, IH, IX
    SP_VISEME_7   equ 7    ;     // w, UW
    SP_VISEME_8   equ 8    ;     // OW
    SP_VISEME_9   equ 9    ;     // AW
    SP_VISEME_10  equ 10   ;     // OY
    SP_VISEME_11  equ 11   ;     // AY
    SP_VISEME_12  equ 12   ;     // h
    SP_VISEME_13  equ 13   ;     // r
    SP_VISEME_14  equ 14   ;     // l
    SP_VISEME_15  equ 15   ;     // s, z
    SP_VISEME_16  equ 16   ;     // SH, CH, JH, ZH
    SP_VISEME_17  equ 17   ;     // TH, DH
    SP_VISEME_18  equ 18   ;     // f, v
    SP_VISEME_19  equ 19   ;     // d, t, n
    SP_VISEME_20  equ 20   ;     // k, g, NG
    SP_VISEME_21  equ 21   ;     // p, b, m


   SPF_DEFAULT equ 0
   SPF_ASYNC   equ 1
   SPF_PURGEBEFORESPEAK equ 2
   SPF_IS_FILENAME   equ 4
   SPF_IS_XML  equ 8
   SPF_IS_NOT_XML equ 16
   SPF_PERSIST_XML   equ 32
   SPF_NLP_SPEAK_PUNC   equ 64
   SPF_NLP_MASK   equ SPF_NLP_SPEAK_PUNC
   SPF_VOICE_MASK equ SPF_ASYNC or SPF_PURGEBEFORESPEAK or SPF_IS_FILENAME or SPF_IS_XML or SPF_IS_NOT_XML or SPF_NLP_MASK or SPF_PERSIST_XML
   SPF_UNUSED_FLAGS  equ NOT SPF_VOICE_MASK

   SPFM_OPEN_READONLY   equ 0 
   SPFM_OPEN_READWRITE  equ SPFM_OPEN_READONLY + 1 
   SPFM_CREATE equ SPFM_OPEN_READWRITE + 1 
   SPFM_CREATE_ALWAYS   equ SPFM_CREATE + 1 
   SPFM_NUM_MODES equ SPFM_CREATE_ALWAYS + 1 

   SPREG_USER_ROOT                     TEXTEQU   <HKEY_CURRENT_USER\SOFTWARE\Microsoft\Speech>
   SPREG_LOCAL_MACHINE_ROOT            TEXTEQU   <HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Speech>
   SPCAT_AUDIOOUT                      TEXTEQU   <HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Speech\AudioOutput>
   SPCAT_AUDIOIN                       TEXTEQU   <HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Speech\AudioInput>
   SPCAT_VOICES                        TEXTEQU   <HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Speech\Voices>

SPVOICESTATUS struc 
    ulCurrentStream     dd ?  ;ULONG 
    ulLastStreamQueued  dd ?  ;ULONG 
    hrLastResult        dd ?  ;HRESULT 
    dwRunningState      dd ?  ;DWORD 
    ulInputWordPos      dd ?  ;ULONG 
    ulInputWordLen      dd ?  ;ULONG 
    ulInputSentPos      dd ?  ;ULONG 
    ulInputSentLen      dd ?  ;ULONG 
    lBookmarkId         dd ?  ;LONG 
    PhonemeId           dd ?  ;SPPHONEID 
    VisemeId            dd ?  ;SPVISEMES
    dwReserved1         dd ?  ;DWORD 
    dwReserved2         dd ?  ;DWORD 
SPVOICESTATUS  ends

SPAUDIOSTATUS struc 
    cbFreeBuffSpace  dd ? ;LONG 
    cbNonBlockingIO  dd ? ;ULONG 
    State            dd ? ;SPAUDIOSTATE ???????
    CurSeekPos       dq ? ;ULONGLONG 
    CurDevicePos     dq ? ;ULONGLONG 
    dwReserved1      dd ? ;DWORD 
    dwReserved2      dd ? ;DWORD 
SPAUDIOSTATUS ends 


;-=================================================================================-
sLIBID_MS_SPEECH                 MGUID (C866CA3A-32F7-11D2-9602-00C04F8EE628)
;-=================================================================================-
sCLSID_SpNotifyTranslator        MGUID (E2AE5372-5D40-11D2-960E-00C04F8EE628)
sCLSID_SpObjectTokenCategory     MGUID (A910187F-0C7A-45AC-92CC-59EDAFB77B53)
sCLSID_SpObjectToken             MGUID (EF411752-3736-4CB4-9C8C-8EF4CCB58EFE)
sCLSID_SpResourceManager         MGUID (96749373-3391-11D2-9EE3-00C04F797396)
sCLSID_SpStreamFormatConverter   MGUID (7013943A-E2EC-11D2-A086-00C04F8EF9B5)
sCLSID_SpMMAudioEnum             MGUID (AB1890A0-E91F-11D2-BB91-00C04F8EE6C0)
sCLSID_SpMMAudioIn               MGUID (CF3D2E50-53F2-11D2-960C-00C04F8EE628)
sCLSID_SpMMAudioOut              MGUID (A8C680EB-3D32-11D2-9EE7-00C04F797396)
sCLSID_SpRecPlayAudio            MGUID (FEE225FC-7AFD-45E9-95D0-5A318079D911)
sCLSID_SpStream                  MGUID (715D9C59-4442-11D2-9605-00C04F8EE628)
sCLSID_SpVoice                   MGUID (96749377-3391-11D2-9EE3-00C04F797396)
sCLSID_SpSharedRecoContext       MGUID (47206204-5ECA-11D2-960F-00C04F8EE628)
sCLSID_SpInprocRecognizer        MGUID (41B89B6B-9399-11D2-9623-00C04F8EE628)
sCLSID_SpSharedRecognizer        MGUID (3BEE4890-4FE9-4A37-8C1E-5E7E12791C1F)
sCLSID_SpLexicon                 MGUID (0655E396-25D0-11D3-9C26-00C04F8EF87C)
sCLSID_SpUnCompressedLexicon     MGUID (C9E37C15-DF92-4727-85D6-72E5EEB6995A)
sCLSID_SpCompressedLexicon       MGUID (90903716-2F42-11D3-9C26-00C04F8EF87C)
sCLSID_SpPhoneConverter          MGUID (9185F743-1143-4C28-86B5-BFF14F20E5C8)
sCLSID_SpNullPhoneConverter      MGUID (455F24E9-7396-4A16-9715-7C0FDBE3EFE3)
;-=================================================================================-


sISpVoice  MGUID (6C44DF74-72B9-4992-A1EC-EF996E0422D4)
;-================================================================-
ISpVoice_DisplayUI                     equ   94h
ISpVoice_IsUISupported                 equ   90h
ISpVoice_SpeakCompleteEvent            equ   8ch
ISpVoice_GetSyncSpeakTimeout           equ   88h
ISpVoice_SetSyncSpeakTimeout           equ   84h
ISpVoice_WaitUntilDone                 equ   80h
ISpVoice_GetVolume                     equ   7ch
ISpVoice_SetVolume                     equ   78h
ISpVoice_GetRate                       equ   74h
ISpVoice_SetRate                       equ   70h
ISpVoice_GetAlertBoundary              equ   6ch
ISpVoice_SetAlertBoundary              equ   68h
ISpVoice_GetPriority                   equ   64h
ISpVoice_SetPriority                   equ   60h
ISpVoice_Skip                          equ   5ch
ISpVoice_GetStatus                     equ   58h
ISpVoice_SpeakStream                   equ   54h
ISpVoice_Speak                         equ   50h
ISpVoice_GetVoice                      equ   4ch
ISpVoice_SetVoice                      equ   48h
ISpVoice_Resume                        equ   44h
ISpVoice_Pause                         equ   40h
ISpVoice_GetOutputStream               equ   3ch
ISpVoice_GetOutputObjectToken          equ   38h
ISpVoice_SetOutput                     equ   34h
ISpVoice_GetInfo                      equ   30h
ISpVoice_GetEvents                    equ   2ch
ISpVoice_SetInterest                  equ   28h
ISpVoice_GetNotifyEventHandle         equ   24h
ISpVoice_WaitForNotifyEvent           equ   20h
ISpVoice_SetNotifyWin32Event          equ   1ch
ISpVoice_SetNotifyCallbackInterface   equ   18h
ISpVoice_SetNotifyCallbackFunction    equ   14h
ISpVoice_SetNotifyWindowMessage       equ   10h
ISpVoice_SetNotifySink                equ   0ch
ISpVoice_Release                      equ   08h
ISpVoice_Addref                       equ   04h
ISpVoice_QueryInterface               equ   00h


sISpObjectTokenCategory    MGUID (2D3D3845-39AF-4850-BBF9-40B49780011D)
;-=====================================================================-
ISpObjectTokenCategory_GetDefaultTokenId                 equ   50h
ISpObjectTokenCategory_SetDefaultTokenId                 equ   4ch
ISpObjectTokenCategory_EnumTokens                        equ   48h
ISpObjectTokenCategory_GetDataKey                        equ   44h
ISpObjectTokenCategory_GetId                             equ   40h
ISpObjectTokenCategory_SetId                             equ   3ch
ISpObjectTokenCategory_EnumValues                        equ   38h
ISpObjectTokenCategory_EnumKeys                          equ   34h
ISpObjectTokenCategory_DeleteValue                       equ   30h
ISpObjectTokenCategory_DeleteKey                         equ   2ch
ISpObjectTokenCategory_CreateKey                         equ   28h
ISpObjectTokenCategory_OpenKey                           equ   24h
ISpObjectTokenCategory_GetDWORD                          equ   20h
ISpObjectTokenCategory_SetDWORD                          equ   1ch
ISpObjectTokenCategory_GetStringValue                    equ   18h
ISpObjectTokenCategory_SetStringValue                    equ   14h
ISpObjectTokenCategory_GetData                           equ   10h
ISpObjectTokenCategory_SetData                           equ   0ch
ISpObjectTokenCategory_Release                           equ   08h
ISpObjectTokenCategory_Addref                            equ   04h
ISpObjectTokenCategory_QueryInterface                    equ   00h


sISpObjectToken   MGUID (14056589-E16C-11D2-BB90-00C04F8EE6C0)
;-===========================================================-
ISpObjectToken_MatchesAttributes                 equ   60h
ISpObjectToken_DisplayUI                         equ   5ch
ISpObjectToken_IsUISupported                     equ   58h
ISpObjectToken_Remove                            equ   54h
ISpObjectToken_RemoveStorageFileName             equ   50h
ISpObjectToken_GetStorageFileName                equ   4ch
ISpObjectToken_CreateInstance                    equ   48h
ISpObjectToken_GetCategory                       equ   44h
ISpObjectToken_GetId                             equ   40h
ISpObjectToken_SetId                             equ   3ch
ISpObjectToken_EnumValues                        equ   38h
ISpObjectToken_EnumKeys                          equ   34h
ISpObjectToken_DeleteValue                       equ   30h
ISpObjectToken_DeleteKey                         equ   2ch
ISpObjectToken_CreateKey                         equ   28h
ISpObjectToken_OpenKey                           equ   24h
ISpObjectToken_GetDWORD                          equ   20h
ISpObjectToken_SetDWORD                          equ   1ch
ISpObjectToken_GetStringValue                    equ   18h
ISpObjectToken_SetStringValue                    equ   14h
ISpObjectToken_GetData                           equ   10h
ISpObjectToken_SetData                           equ   0ch
ISpObjectToken_Release                           equ   08h
ISpObjectToken_Addref                            equ   04h
ISpObjectToken_QueryInterface                    equ   00h


sISpStream  MGUID  (12E3CCA9-7518-44C5-A5E7-BA5A79CB929E)
;-================================================================-
ISpStream_Close                        equ   48h
ISpStream_BindToFile                   equ   44h
ISpStream_GetBaseStream                equ   40h
ISpStream_SetBaseStream                equ   3ch           
ISpStream_GetFormat                    equ   38h
ISpStream_Clone                        equ   34h
ISpStream_Stat                         equ   30h
ISpStream_UnlockRegion                 equ   2ch
ISpStream_LockRegion                   equ   28h
ISpStream_Revert                       equ   24h
ISpStream_Commit                       equ   20h
ISpStream_CopyTo                       equ   1ch
ISpStream_SetSize                      equ   18h
ISpStream_Seek                         equ   14h
ISpStream_Write                        equ   10h
ISpStream_Read                         equ   0ch
ISpStream_Release                      equ   08h
ISpStream_Addref                       equ   04h
ISpStream_QueryInterface               equ   00h


sISpStreamFormat  MGUID    (BED530BE-2606-4F4D-A1C0-54C5CDA5566F)
;-================================================================-
ISpStreamFormat_GetFormat                    equ   38h
ISpStreamFormat_Clone                        equ   34h
ISpStreamFormat_Stat                         equ   30h
ISpStreamFormat_UnlockRegion                 equ   2ch
ISpStreamFormat_LockRegion                   equ   28h
ISpStreamFormat_Revert                       equ   24h
ISpStreamFormat_Commit                       equ   20h
ISpStreamFormat_CopyTo                       equ   1ch
ISpStreamFormat_SetSize                      equ   18h
ISpStreamFormat_Seek                         equ   14h
ISpStreamFormat_Write                        equ   10h
ISpStreamFormat_Read                         equ   0ch
ISpStreamFormat_Release                      equ   08h
ISpStreamFormat_Addref                       equ   04h
ISpStreamFormat_QueryInterface               equ   00h


sIEnumSpObjectTokens  MGUID (06B64F9E-7FDA-11D2-B4F2-00C04F797396)
;-================================================================-
IEnumSpObjectTokens_GetCount                     equ   20h
IEnumSpObjectTokens_Item                         equ   1ch
IEnumSpObjectTokens_Clone                        equ   18h
IEnumSpObjectTokens_Reset                        equ   14h
IEnumSpObjectTokens_Skip                         equ   10h
IEnumSpObjectTokens_Next                         equ   0ch
IEnumSpObjectTokens_Release                      equ   08h
IEnumSpObjectTokens_Addref                       equ   04h
IEnumSpObjectTokens_QueryInterface               equ   00h
;
; MS Speech v5 Data Translation from SDK by NaN, 2002.   Rev 1.2
; 







;;;;;